#!/bin/bash
# Copyright (c) 2000, 2005 IBM Corp. - All Rights Reserved.
# IBM makes no representations or warranties about the suitability of
# this program, either express or implied, including but not limited to
# the implied warranties of merchantability, fitness for a particular
# purpose, or non-infringement. 
  
#
#  Refresh the war file so that it will pick up the files now specified in the user_jars.list file.  
#  This is onl;y needed on Websphere - as this is the only application server that requires the jar
#  files to be in the archive.                                                                                                 
# usage: refresh_war.sh 
#


#
# refresh war
#

RefreshWar() {
    ${ECHO} "Refreshing the web archive"
    
    #dir for refreshing the war.. will be cleaned up
    TMP_WEBAPP_DIR=$TOP/tmp_ccd_webapp
        
    cd ${TOP}
    ${MKDIR} $TMP_WEBAPP_DIR
    
    #location of websphere shipped war file.
    CCD_WAR_FILE=$TOP/etc/default/websphere/webapps/ccd.war
    
    cd $TMP_WEBAPP_DIR
    
    # extract the existing war file into the temporary directory      
    ${ECHO} "Extracting the existing war file ..."
    jar xf $CCD_WAR_FILE 
    
    # move out the jsp jar file 
    mv $TMP_WEBAPP_DIR/WEB-INF/lib/ccd_jsp.jar ${TMP_DIR}
    # delete the other jar files in the lib directory
    rm $TMP_WEBAPP_DIR/WEB-INF/lib/*
    
    # Need to create a manifest file containing a Class-Path attribute, which allows us to specify the order of the jars in the classpath     
    ${ECHO} Manifest-Version: 1.0 > ${TMP_MANIFEST}
    ${ECHO} "Created-By: WPC (IBM Corporation)" >> ${TMP_MANIFEST}
    CLASS_PATH_VAR="Class-Path:"
    
    # The system jars logic below needs to be kept the same as the logic in the install.sh CreateWar functions, as we want to build the initial
    # war in the same way are we rebuild the war.    
    mv ${TMP_DIR}/ccd_jsp.jar $TMP_WEBAPP_DIR/WEB-INF/lib
    cp $JARDIR/ccd_svr.jar $TMP_WEBAPP_DIR/WEB-INF/lib
    
    # obtain the list of system jars by processing ccd.rc    
    ${CAT} $TOP/setup/ccd.rc|${GREP} 'AddJar $JARDIR'|${GREP} -v "servlet"|${GREP} -v "j2ee"|${SED} -e 's|^.*AddJar $JARDIR||'|sort|uniq > ${TMP_FILE}
        
    # system jars
    while read LINE; do             
        JAR_BASE_NAME=`basename "$LINE"`
        echo Refreshing $JAR_BASE_NAME
        
        #copy the jar to web-inf/lib, $line is already prefixed '/'
        ${CP} $JARDIR$LINE $TMP_WEBAPP_DIR/WEB-INF/lib/
        
        # change space to %20 so that file urls will work with spaces in filename and directory names.   
        JAR_FOR_MANIFEST=`${ECHO} $JAR_BASE_NAME | sed -e 's| |%20|' | sed -e 's|//|/|'  | sed -e 's|^/||'`
        CLASS_PATH_VAR="$CLASS_PATH_VAR $JAR_FOR_MANIFEST "
        ${ECHO} "$CLASS_PATH_VAR" >>${TMP_MANIFEST}
        
        # reset this variable - as we have added in the attribute name Class_Path
        CLASS_PATH_VAR=
    
    done < ${TMP_FILE}
    
    # user jars    
    # Get the environment variable containing the user classpath - it is in the form file$PATH_SEPARATORfile. 
    ${ECHO} ${CCD_USER_CLASSPATH} > ${TMP_FILE}      
    ${CAT} ${TMP_FILE} | ${TR} '${PATH_SEPARATOR}' '\n' > ${TMP_FILE}.2          
                    
    while read LINE; do                
      # We need to check to see if the jar file has already been added to the war file, if it has then we do not want to 
      # copy over the jar file. This will ensure that if there are 2 jar files of the same name in the list then the first
      # one is picked up and the second one is ignored. 
      JAR_BASE_NAME=`basename "$LINE"`      
      if [ ! -r "$TMP_WEBAPP_DIR/WEB-INF/lib/$JAR_BASE_NAME" ]; then 
      
         echo Refreshing userjar $JAR_BASE_NAME
         
         # copy userjar to web-inf/lib
         ${CP} "$LINE" $TMP_WEBAPP_DIR/WEB-INF/lib/
         
         # change spaces to %20 in manifest so that file urls will work.
         JAR_NAME_FOR_MANIFEST=`${ECHO} ${JAR_BASE_NAME} | sed -e 's| |%20|' `
         ${ECHO} " $JAR_NAME_FOR_MANIFEST " >>${TMP_MANIFEST}
         
      else
          ${ECHO} Skipping $LINE, already in war.
      fi
    done < ${TMP_FILE}.2

    #add another empty line to manifest..
    ${ECHO} "" >> ${TMP_MANIFEST} 
    ${ECHO} "" >> ${TMP_MANIFEST}
          
    #cleanup the tmp list files                       
    ${RM} ${TMP_FILE} 2>/dev/null
    ${RM} ${TMP_FILE} 2>/dev/null
    ${RM} ${TMP_FILE}.2 2>/dev/null
    ${RM} ${TMP_FILE}.2 2>/dev/null
      
    cd $TMP_WEBAPP_DIR                                
                                     
    #fix paths if running in a cygwin test shell.    
    case "`uname`" in
      CYGWIN*) 
        TMP_MANIFEST=`cygpath --windows $TMP_MANIFEST`
        CCD_WAR_FILE=`cygpath --windows $CCD_WAR_FILE`
      ;;
    esac
    
    ${ECHO} "Creating the new refreshed war file ..."
    #echo jar cmf ${TMP_MANIFEST} $CCD_WAR_FILE .

    ${JAVA_HOME}/bin/jar cmf ${TMP_MANIFEST} $CCD_WAR_FILE .     

    cd $TOP
    ${RM} $TMP_WEBAPP_DIR
}

#
# cleanup
#

Cleanup() {
    ${ECHO} "$HEADER_TXT cleaning up"

    cd $TOP
    ${RM} $TMP_DIR
}

#
# main
#

# Run ccd.rc so that the war file is in sync with the classpath and the non-applicaiton server processes including the workflow
# engine will see the same classpath as the war file.           
. ${TOP}/setup/ccd.rc

#dir for tmp files (will be cleaned up)
TMP_DIR="$TOP/refresh_log"
${MKDIR} ${TMP_DIR}       

#tmp file
TMP_FILE="${TMP_DIR}/refresh_tmp.txt"
TMP_MANIFEST="$TMP_DIR/MANIFEST.MF"

RefreshWar
Cleanup
